@@ -38,7 +38,8 @@ STDERR=summary_concatenated_stderr.log
 INFO=concatenated.info
 
 cat "${TARGETINFO}" "${TARGETINFO}" >"${INFO}"
-$LCOV --summary "${INFO}" 2> >(grep -v Devel::Cover: > ${STDERR}) >${STDOUT}
+# generated data is not consistent -ingore for now
+$LCOV --summary "${INFO}" --ignore inconsistent,inconsistent 2> >(grep -v Devel::Cover: > ${STDERR}) >${STDOUT}
 RC=$?
 cat "${STDOUT}" "${STDERR}"
 
